/*

SmarterMailMon: Mail account monitor that can be used to watch for new 
messages in POP and IMAP accounts.

Copyright (C) 2007  SmarterTools

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

*/

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace SmarterMailMon
{
    public partial class AddEditAccount : Form
    {
        private string oldAccountName = "";
        private bool addNewAccount = true;
        private MailAccount account = new MailAccount();

        public AddEditAccount()
        {
            InitializeComponent();

            FillLists();
        }

        private void FillLists()
        {
            lstMailServerType.Items.Add("SmarterMail");
            lstMailServerType.Items.Add("IMail");
            lstMailServerType.Items.Add("MailEnable");
            lstMailServerType.Items.Add("Other");
            
            lstMailServerType.SelectedIndex = 0;
        }

        public void SetAccount(MailAccount account)
        {
            addNewAccount = false;
            oldAccountName = account.name;

            txtName.Text = account.name;
            txtServerAddress.Text = account.serverAddress;
            txtUserName.Text = account.userName;
            txtWebMailUrl.Text = account.webMailUrl;
            txtPassword.Text = account.password;

            rbPOP.Checked = account.accountType == AccountType.POP;
            rbIMAP.Checked = account.accountType == AccountType.IMAP;

            switch (account.serverType)
            {
                case MailServerType.SmarterMail:    lstMailServerType.SelectedIndex = 0;    break;
                case MailServerType.Imail:          lstMailServerType.SelectedIndex = 1;    break;
                case MailServerType.MailEnable:     lstMailServerType.SelectedIndex = 2;    break;
                case MailServerType.Other:          lstMailServerType.SelectedIndex = 3;    break;
            }
        }

        private bool SetAccountValues(ref string errorMessage)
        {
            account.name = txtName.Text.Trim();
            if (account.name.Length == 0)
            {
                errorMessage = "Please enter the name of the account.";
                return false;
            }
            if (addNewAccount && MailAccountCollection.accountCollection.Exists(account.name))
            {
                errorMessage = "An account with that name already exists.  Please choose a unique name.";
                return false;
            }
            
            account.serverAddress = txtServerAddress.Text.Trim();
            if (account.serverAddress.Length == 0)
            {
                errorMessage = "Please enter the mail server address.";
                return false;
            }

            account.userName = txtUserName.Text.Trim();
            if (account.userName.Length == 0)
            {
                errorMessage = "Please enter the user name for the account.";
                return false;
            }

            account.webMailUrl = txtWebMailUrl.Text.Trim(); // webmail url is not required
            account.password = txtPassword.Text;

            string serverTypeStr = lstMailServerType.SelectedItem.ToString();
            switch (serverTypeStr.ToLowerInvariant())
            {
                case "smartermail":     account.serverType = MailServerType.SmarterMail;    break;
                case "imail":           account.serverType = MailServerType.Imail;          break;
                case "mailenable":      account.serverType = MailServerType.MailEnable;     break;
                case "other":           account.serverType = MailServerType.Other;          break;
            }

            account.accountType = rbPOP.Checked ? AccountType.POP : AccountType.IMAP;

            return true;
        }

        private void btnOK_Click(object sender, EventArgs e)
        {
            string errorMessage = "";
            bool success = SetAccountValues(ref errorMessage);

            if (success)
            {
                if (addNewAccount)
                    MailAccountCollection.accountCollection.AddAccount(account);
                else
                {
                    if (oldAccountName.ToLowerInvariant() == account.name.ToLowerInvariant())
                        MailAccountCollection.accountCollection.UpdateAccount(account);
                    else    // account name changed so we have to remove the old account and add a new one
                    {
                        MailAccountCollection.accountCollection.RemoveAccount(oldAccountName);
                        MailAccountCollection.accountCollection.AddAccount(account);
                    }
                }

                this.Close();
            }
            else // error
                MessageBox.Show(errorMessage, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            
        }

        private void btnCancel_Click(object sender, EventArgs e)
        {
            this.Close();
        }
    }
}