/*

SmarterMailMon: Mail account monitor that can be used to watch for new 
messages in POP and IMAP accounts.

Copyright (C) 2007  SmarterTools

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

*/

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace SmarterMailMon
{
    public partial class EditAccounts : Form
    {
        private delegate void UpdateMailAccountListDelegate();
        private object updateLockObj = new object();

        public EditAccounts()
        {
            InitializeComponent();

            UpdateMailAccountList();
            MailAccountCollection.accountCollection.collectionUpdateEvent += new MailAccountCollectionUpdateDelegate(accountCollection_collectionUpdateEvent);
        }

        private void accountCollection_collectionUpdateEvent(object sender)
        {
            Invoke(new UpdateMailAccountListDelegate(UpdateMailAccountList));
        }

        private void UpdateMailAccountList()
        {
            lock (updateLockObj)
            {
                lstAccounts.Items.Clear();

                MailAccount[] mailAccounts = MailAccountCollection.accountCollection.MailAccounts;
                foreach (MailAccount accountItem in mailAccounts)
                    lstAccounts.Items.Add(accountItem.name);
            }
        }

        private void btnAdd_Click(object sender, EventArgs e)
        {
            AddEditAccount addAccountForm = new AddEditAccount();
            addAccountForm.ShowDialog(this);
        }

        private void btnEdit_Click(object sender, EventArgs e)
        {
            if (lstAccounts.SelectedIndex == -1)
                return;

            string accountName = lstAccounts.SelectedItem.ToString();
            MailAccount account = MailAccountCollection.accountCollection.GetAccount(accountName);
            if (account == null)
                return;

            AddEditAccount editAccountForm = new AddEditAccount();
            editAccountForm.SetAccount(account);
            editAccountForm.ShowDialog(this);
        }

        private void btnRemove_Click(object sender, EventArgs e)
        {
            if (lstAccounts.SelectedIndex == -1)
                return;

            string accountName = lstAccounts.SelectedItem.ToString();
            MailAccountCollection.accountCollection.RemoveAccount(accountName);
        }

        private void btnClose_Click(object sender, EventArgs e)
        {
            this.Close();
        }

        private void lstAccounts_DoubleClick(object sender, EventArgs e)
        {
            btnEdit_Click(sender, e);
        }

        private void EditAccounts_FormClosing(object sender, FormClosingEventArgs e)
        {
            MailAccountCollection.accountCollection.collectionUpdateEvent -= new MailAccountCollectionUpdateDelegate(accountCollection_collectionUpdateEvent);
        }
    }
}